#[non_exhaustive]pub enum Error {
KeyFormat,
Decode,
Decap,
Unseal,
Seal,
Rng,
Internal,
UnsupportedVersion(u8),
UnsupportedSuite,
InfoExceedsSize,
EmptyCiphertext,
}Expand description
Failure modes with encryption or keys
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
KeyFormat
Provided key is malformed: bad encoding, checksum, HRP, or length.
Decode
The sealed message is too short or malformed.
Decap
KEM decapsulation failed.
Unseal
AEAD authentication failed: tampered ciphertext, wrong recipient, wrong info.
Seal
Sealing the message failed.
Rng
The operating system CSPRNG is unavailable, so no secure randomness could be drawn.
Internal
An HPKE state that this construction never produces. Critical library bug.
UnsupportedVersion(u8)
The provided ciphertext contains an invalid or unsupported version.
UnsupportedSuite
The provided ciphertext specifies an unsupported cryptographic suite.
InfoExceedsSize
The provided info exceeds the max size
EmptyCiphertext
The provided ciphertext is empty